
``selkie.string`` — Strings
===========================

.. automodule:: selkie.string

General functionality
---------------------

.. autofunction:: unidescribe
.. autofunction:: isword
.. autofunction:: lines

Conversion to ASCII
-------------------

.. autofunction:: as_ascii
.. autofunction:: from_ascii
.. autofunction:: quoted
.. autofunction:: deaccent

Formatting dates/times and sizes
--------------------------------

.. autofunction:: dtstr
.. autofunction:: sizestr
.. autofunction:: elapsed_time_str
.. autofunction:: timestr

Expand environment variables
----------------------------

.. autofunction:: expand_envvars


